@@ -22,7 +22,7 @@ centroid <- function(x, ...) {
 centroid.track_xy <- function(x, spatial = FALSE, ...) {
   xx <- colMeans(x[, c("x_", "y_")])
   if (spatial) {
-    sp::SpatialPoints(cbind(xx["x_"], xx["y_"]))
+    sf::st_point(xx)
   } else {
     xx
   }
